@@ -78,7 +78,7 @@ impl DownStreamInner {
             if let Some(byte_count) = Self::get_data_stream(&mut raw_stream, &mut self.internal_data_buffer) {
                 if byte_count > 0 {
 
-                    if let Err(e) = data_out.send(FullDuplexTcpState::UpStreamWrite(self.internal_data_buffer.clone())) {
+                    if let Err(_e) = data_out.send(FullDuplexTcpState::UpStreamWrite(self.internal_data_buffer.clone())) {
                         
                         //Self::handle_error(format!("Failed to send UpStreamWrite to main thread: {}", e).as_str());
                         let _ = raw_stream.shutdown(Shutdown::Both);
@@ -151,7 +151,7 @@ impl DownStreamInner {
             if let Some(byte_count) = Self::get_data_stream(&mut tls_stream, &mut self.internal_data_buffer) {
                 if byte_count > 0 {
 
-                    if let Err(e) = data_out.send(FullDuplexTcpState::UpStreamWrite(self.internal_data_buffer.clone())) {
+                    if let Err(_e) = data_out.send(FullDuplexTcpState::UpStreamWrite(self.internal_data_buffer.clone())) {
                         
                         //Self::handle_error(format!("Failed to send UpStreamWrite to main thread: {}", e).as_str());
                         let _ = tls_stream.shutdown();
@@ -294,7 +294,7 @@ impl UpStreamInner {
             if let Some(byte_count) = Self::get_data_stream(&mut raw_stream, &mut self.internal_data_buffer) {
                 if byte_count > 0 {
 
-                    if let Err(e) = data_out.send(FullDuplexTcpState::DownStreamWrite(self.internal_data_buffer.clone())) {
+                    if let Err(_e) = data_out.send(FullDuplexTcpState::DownStreamWrite(self.internal_data_buffer.clone())) {
                         
                         //Self::handle_error(format!("Failed to send DownStreamWrite to main thread: {}", e).as_str());
                         let _ = raw_stream.shutdown(Shutdown::Both);
@@ -363,7 +363,7 @@ impl UpStreamInner {
             if let Some(byte_count) = Self::get_data_stream(&mut tls_stream, &mut self.internal_data_buffer) {
                 if byte_count > 0 {
 
-                    if let Err(e) = data_out.send(FullDuplexTcpState::DownStreamWrite(self.internal_data_buffer.clone())) {
+                    if let Err(_e) = data_out.send(FullDuplexTcpState::DownStreamWrite(self.internal_data_buffer.clone())) {
 
                         //Self::handle_error(format!("Failed to send DownStreamWrite to main thread: {}", e).as_str());
                         let _ = tls_stream.shutdown();
